# This is a firmware package, so binaries (which are not run on the host)
# in the end package are expected.
%define _binaries_in_noarch_packages_terminate_build   0
%global _firmwarepath  /usr/lib/firmware

%global sof_ver 2.2.4
%global tplg_version 2.2.4

Name:           alsa-sof-firmware
Version:        %{sof_ver}
Release:        %mkrel 1
Summary:        Firmware and topology files for Sound Open Firmware project
License:        BSD
Group:          System/Kernel and hardware
URL:            https://www.sofproject.org
Source0:        https://github.com/thesofproject/sof-bin/releases/download/v%{sof_ver}/sof-bin-v%{sof_ver}.tar.xz
BuildRequires:  alsa-utils >= 1.2.8
Obsoletes:		sof-firmware
Provides:		sof-firmware
Provides:		alsa-sof-firmware

%description
This package contains the firmware binaries for the Sound Open Firmware project.

%package debug
Requires:       alsa-sof-firmware
Summary:        Debug files for Sound Open Firmware project
License:        BSD

%description debug
This package contains the debug files for the Sound Open Firmware project.


%prep
%setup -qn sof-bin-v%{sof_ver}

mkdir -p firmware/intel/sof

# we have the version in the package name
mv sof-v%{sof_ver}/* firmware/intel/sof

# move topology files
mv sof-tplg-v%{sof_ver} firmware/intel/sof-tplg

# remove NXP firmware files
rm LICENCE.NXP
rm -rf firmware/intel/sof-tplg/sof-imx8*

# remove Mediatek firmware files
# why?
# rm -rf firmware/intel/sof-tplg/sof-mt8*

%build
# SST topology files (not SOF related, but it's a Intel hw support
# and this package seems a good place to distribute them
alsatplg -c /usr/share/alsa/topology/hda-dsp/skl_hda_dsp_generic-tplg.conf \
         -o firmware/skl_hda_dsp_generic-tplg.bin
         
%install
mkdir -p %{buildroot}%{_firmwarepath}
cp -ra firmware/* %{buildroot}%{_firmwarepath}

# gather files and directories
FILEDIR=$(pwd)
pushd %{buildroot}/%{_firmwarepath}
find -P . -name "*.ri" | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.files
#find -P . -name "*.tplg" | sed -e '/^.$/d' >> $FILEDIR/alsa-sof-firmware.files
find -P . -name "*.ldc" | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.debug-files
find -P . -type d | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.dirs
popd

sed -i -e 's:^./::' alsa-sof-firmware.{files,debug-files,dirs}
sed -i -e 's!^!/usr/lib/firmware/!' alsa-sof-firmware.{files,debug-files,dirs}
sed -e 's/^/%%dir /' alsa-sof-firmware.dirs >> alsa-sof-firmware.files

cat alsa-sof-firmware.files
 
%files -f alsa-sof-firmware.files
 
%doc README* LICENCE* Notice.*
%dir %{_firmwarepath}

# Licence: 3-clause BSD
%config(noreplace) %{_firmwarepath}/*.bin

# Licence: 3-clause BSD
# .. for files with suffix .tplg
%config(noreplace) %{_firmwarepath}/intel/sof-tplg/*

# Licence: SOF (3-clause BSD plus others)
# .. for files with suffix .ri
%files debug -f alsa-sof-firmware.debug-files

%changelog
* Sun Jan 08 2023 onkelho <oh.quait at gmail.com> - 2.2.4-1pclos2023
- new version released

* Wed May 25 2022 onkelho <oh.quait at gmail.com> - 2.1.1-10pclos2022
- rebuild and add real the 2 new files in sof-bin-v2.1.1/sof-tplg-v2.1.1/
- remove sof-firmware...from quait-repo
- remove buildarch:noarch, pclos just have x86_64 section on repo
- - from fualty sof-firmware onkelho <oh.quait at gmail.com> - 2.1.1-3pclos2022
- i used the /lib/firmware-path - pclos use /usr/lib/firmware
- - fix post and postun
- - nor problem to put in /lib/firmaware/
- - keep links to compatible with old-pclos /lib/firmware/intel/sof+sof-tplg
- + /lib/firmware/skl_hda_dsp_generic-tplg.bin to /usr/lib/firmware
- impprofes few open-suse, 
- 2.1.1 is bugfix-rel from 2.1
- 3964a9d audio: volume: initialize variables before using
- e7c5da4 buffer: dereference before null check fix

* Wed May 04 2022 TerryN <terryn94 at gmail.com>  2.1.1-1pclos2022
- update

* Mon Sep 06 2021 TerryN <terryn94 at gmail.com>  1.8-1pclos2021
- new package for pclinuxos

